/*
 *  SingIt Lyrics Displayer
 *  Copyright (C) 2000 - 2002 Jan-Marek Glogowski <glogow@stud.fbi.fh-darmstadt.de>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */


#ifndef __DISPLAYER_SDL_H__
#define __DISPLAYER_SDL_H__

#include "singit/macros.h"

#include "displayer_sdl_status.h"

#ifdef __cplusplus
extern "C" {
#endif // __cplusplus

gint displayer_sdl_disable_func(gpointer data);
void displayer_sdl_get_position(gint *x, gint *y);

// gboolean displayer_sdl_event_thread_func(gpointer data);

#ifdef __cplusplus
}
#endif // __cplusplus

#endif // __DISPLAYER_SDL_H__
